@@ -763,10 +763,6 @@ printk("PPP_DEBUG atr0-ok1:LCNT set LOW(bit OFF)\n");
 
 #endif		/* FHKB LOW */
 
-#if BASIL_PPP_DEBUG
-printk("PPP_DEBUG atr0-ok1:LCNT set LOW(bit OFF)\n");
-#endif
-			basil_mc_sts = STS_IDLE;
 #if BASIL_PPP_DEBUG
 			printk("PPP_DEBUG : ath0-ok \n");
 #endif
@@ -1157,8 +1153,21 @@ printk("PPP_DEBUG atd-def:LCNT set LOW(bit OFF)\n");
 			}
 			break;
 		case EVT_INIT:
+#if 1	/* 040115 sugiyama wrote */
+		case EVT_LHKB_LOW:
+		case EVT_DISCON:
+		case EVT_ATD:
+#endif
 			break;
 		default:
+#if 1	/* 040115 sugiyama wrote */
+			if ( buf == NULL ){
+#if BASIL_PPP_DEBUG
+				printk("PPP:Warning Incoming event which isn't assumed evt = 0x%x\n", evt);
+#endif
+				break;
+			}
+#endif
 #if BASIL_PPP_DEBUG
 printk("\nPPP_DEBUG, atd-def buf =");
 
@@ -1167,6 +1176,7 @@ for ( i = 0 ; i < strlen(buf) ; i ++ ){
 }
 printk("\n");
 #endif
+
 			/* check ATDT command LOCAL ECHO */
 			if ( 1 == strlen(buf) ){			/* 1byte data chack */
 				 break;
