@@ -39,7 +39,7 @@
 /*
  * scheduler variables
  */
-#define VERSION_DATE "<20011203.1609.50>"
+#define VERSION_DATE "<20030619.1708.46>"
 /*
  * We align per-CPU scheduling data on cacheline boundaries,
  * to prevent cacheline ping-pong.
@@ -316,7 +316,8 @@ static inline void re_queue_cpu(struct task_struct *next,
         next->newprio = &newprio_executing;
 }
 #else
-#define re_queue_cpu(a,b)
+#define re_queue_cpu(a,b)        (a)->newprio = &newprio_executing
+
 #endif
 /*
  * Careful!
@@ -625,6 +626,14 @@ static void newprio_executing(struct task_struct *tptr,int newprio)
 	if ((cpu != smp_processor_id()) && tptr->need_resched)
 		smp_send_reschedule(cpu);
 }
+#else
+static void newprio_executing(struct task_struct *tptr,int newprio)
+{
+        if(!newprio || newprio < tptr->effprio){
+		tptr->need_resched = 1;
+        }
+        tptr->effprio = newprio;
+}
 #endif
 
 
@@ -1053,8 +1062,7 @@ same_process:
 }
 static inline struct task_struct *find_process_by_pid(pid_t pid);
 
-static int setscheduler(pid_t pid, int policy, 
-			struct sched_param *param)
+int setscheduler(pid_t pid, int policy, struct sched_param *param)
 {
 	struct sched_param lp;
 	struct task_struct *p;
